--[[
 * ReaScript Name: Slide left split edge to right
 * Description: 
 * Instructions: Select item(s) right from the split. Run this script.
 * Author: AZ
 * Version: 1.0
--]]

dtime = 0.2 -- seconds

slide_count = 0

for i = 1, reaper.CountSelectedMediaItems(0) do
  if slide_count == 0 then
    reaper.Undo_BeginBlock()
  end
  slide_count = slide_count + 1

  right_item = reaper.GetSelectedMediaItem(0, i - 1)
  split_pos = reaper.GetMediaItemInfo_Value(right_item, "D_POSITION")
  right_item_length = reaper.GetMediaItemInfo_Value(right_item, "D_LENGTH")
  right_item_snap = reaper.GetMediaItemInfo_Value(right_item, "D_SNAPOFFSET")
  
  reaper.SetMediaItemInfo_Value(right_item, "D_POSITION", split_pos + dtime)
  reaper.SetMediaItemInfo_Value(right_item, "D_LENGTH", right_item_length - dtime)
  for k = 1, reaper.GetMediaItemNumTakes(right_item) do
    take = reaper.GetMediaItemTake(right_item, k - 1)
    if take then
      off = reaper.GetMediaItemTakeInfo_Value(take, "D_STARTOFFS")
      reaper.SetMediaItemTakeInfo_Value(take, "D_STARTOFFS", off + dtime)
    end
  end

  track = reaper.GetMediaItem_Track(right_item)
  for j = 1, reaper.CountTrackMediaItems(track) do
    left_item = reaper.GetTrackMediaItem(track, j - 1)
    if left_item ~= right_item then
      left_item_pos = reaper.GetMediaItemInfo_Value(left_item, "D_POSITION")
      left_item_length = reaper.GetMediaItemInfo_Value(left_item, "D_LENGTH")
      left_item_end = left_item_pos + left_item_length
      if left_item_end >= split_pos - 0.01 and left_item_end < split_pos + 0.1 then
        reaper.SetMediaItemInfo_Value(left_item, "D_LENGTH", left_item_length + dtime)
      end
    end
  end
end

if slide_count > 0 then
  reaper.Undo_EndBlock("Slide split right", -1)
end

